@@ -1,9 +1,7 @@
+from __future__ import annotations
 import dataclasses
-from datetime import date, datetime
-from marshmallow import fields
-import dateutil.parser
-from typing import Optional
 from ..shared import error as shared_error
+from typing import Optional
 
 
 @dataclasses.dataclass
@@ -11,4 +9,4 @@ class ValidateAPIKeyResponse:
     content_type: str = dataclasses.field()
     status_code: int = dataclasses.field()
     error: Optional[shared_error.Error] = dataclasses.field(default=None)
-    
+    
\ No newline at end of file
