@@ -1,10 +1,11 @@
+from __future__ import annotations
 import dataclasses
-from dataclasses_json import dataclass_json
-from sdk import utils
 from ..shared import filter as shared_filter
+from dataclasses_json import Undefined, dataclass_json
+from sdk import utils
 
 
-@dataclass_json
+@dataclass_json(undefined=Undefined.EXCLUDE)
 @dataclasses.dataclass
 class Filters:
     r"""Filters
@@ -15,4 +16,4 @@ class Filters:
     limit: int = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.field_name('limit') }})
     offset: int = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.field_name('offset') }})
     operator: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.field_name('operator') }})
-    
+    
\ No newline at end of file
