@@ -30,10 +30,12 @@ class Requests:
         
         url = utils.generate_url(base_url, "/v1/eventlog/{requestID}/generate/postman", request.path_params)
         
+        headers = {}
+        headers["user-agent"] = f"speakeasy-sdk/{self._language} {self._sdk_version} {self._gen_version}"
         
         client = self._security_client
         
-        r = client.request("GET", url)
+        r = client.request("GET", url, headers=headers)
         content_type = r.headers.get("Content-Type")
 
         res = operations.GenerateRequestPostmanCollectionResponse(status_code=r.status_code, content_type=content_type)
@@ -57,10 +59,12 @@ class Requests:
         
         url = utils.generate_url(base_url, "/v1/eventlog/{requestID}", request.path_params)
         
+        headers = {}
+        headers["user-agent"] = f"speakeasy-sdk/{self._language} {self._sdk_version} {self._gen_version}"
         
         client = self._security_client
         
-        r = client.request("GET", url)
+        r = client.request("GET", url, headers=headers)
         content_type = r.headers.get("Content-Type")
 
         res = operations.GetRequestFromEventLogResponse(status_code=r.status_code, content_type=content_type)
@@ -87,11 +91,13 @@ class Requests:
         
         url = base_url.removesuffix("/") + "/v1/eventlog/query"
         
+        headers = {}
         query_params = utils.get_query_params(request.query_params)
+        headers["user-agent"] = f"speakeasy-sdk/{self._language} {self._sdk_version} {self._gen_version}"
         
         client = self._security_client
         
-        r = client.request("GET", url, params=query_params)
+        r = client.request("GET", url, params=query_params, headers=headers)
         content_type = r.headers.get("Content-Type")
 
         res = operations.QueryEventLogResponse(status_code=r.status_code, content_type=content_type)
